#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-graph
version:              2.3.0.0
visibility:           public
id:                   hls-graph-2.3.0.0-8cbaJWEq6LS58TCEqe7zAd
key:                  hls-graph-2.3.0.0-8cbaJWEq6LS58TCEqe7zAd
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  f16aa3991a67fbd1447d4361963f84e9
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-graph-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-graph-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-graph-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-2.3.0.0-8cbaJWEq6LS58TCEqe7zAd
depends:
    aeson-2.2.1.0-Def4REbZAAu5MJxZQtCFDo
    async-2.2.6-HlTb8qs1wHD7UNlnrqlxTX base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    extra-1.7.16-7J4flVDuVp79ZQl3ULvjo5 filepath-1.4.300.1
    focus-1.0.3.2-ANZxyusW8i7AaE98VcgdsS
    hashable-1.4.7.0-3mscVqjFvnNHNJmw9rQ9m6
    js-dgtable-0.5.2-JIjvuPD3we7ByE7r2A7oMM
    js-flot-0.8.3-CSwWF2xMOrpIfADJpYok8C
    js-jquery-3.7.1-A5oFixqOOZ08vL9dl2nlDt
    list-t-1.0.5.7-JjJuF2Zbync2OtyMyVtlS1 stm-2.5.1.0
    stm-containers-1.2.1.1-7SiG5HPkuGvL0fYurqkC99 text-2.0.2
    time-1.12.2 transformers-0.6.1.0
    unliftio-0.2.25.1-2YWCJQ4bXOaKV2dFmJlGMH
    unordered-containers-0.2.20.1-CeHDQtVso2t69dwLJnxrjh

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

